@@ -2,7 +2,6 @@ use lettre::smtp::authentication::Credentials;
 use lettre::stub::StubTransport;
 use lettre::{SendableEmail, SmtpClient, Transport};
 use lettre_email::EmailBuilder;
-use std::str;
 
 #[derive(Clone)]
 pub struct Mailer {
@@ -27,51 +26,50 @@ impl Mailer {
             .eq_ignore_ascii_case("true");
 
         return Mailer {
-            from_address: from_address,
-            smtp_server: smtp_server,
-            smtp_username: smtp_username,
-            smtp_password: smtp_password,
-            actually_send: actually_send,
+            from_address,
+            smtp_server,
+            smtp_username,
+            smtp_password,
+            actually_send,
         };
     }
 
     pub fn check_environment_variables() {
         if std::env::var("SMTP_FROM_ADDRESS").is_err() {
             println!(
-                "Note: SMTP_FROM_ADDRESS environment variable is not set, no mail will be sent!"
+                "Note: Mailing disabled; 'SMTP_FROM_ADDRESS' not set."
             );
         }
 
         if std::env::var("SMTP_SERVER").is_err() {
-            println!("Note: SMTP_SERVER environment variable is not set, no mail will be sent!");
+            println!("Note: Mailing disabled; 'SMTP_SERVER' not set.");
         }
 
         if std::env::var("SMTP_USERNAME").is_err() {
-            println!("Note: SMTP_USERNAME environment variable is not set, no mail will be sent!");
+            println!("Note: Mailing disabled; 'SMTP_USERNAME' not set.");
         }
 
         if std::env::var("SMTP_PASSWORD").is_err() {
-            println!("Note: SMTP_PASSWORD environment variable is not set, no mail will be sent!");
+            println!("Note: Mailing disabled; 'SMTP_PASSWORD' not set.");
         }
 
-        if std::env::var("SEND_MAIL").is_err() || !std::env::var("SEND_MAIL").unwrap().eq("true") {
+        if std::env::var("SEND_MAIL").is_err() || !std::env::var("SEND_MAIL").unwrap().eq_ignore_ascii_case("true") {
             println!(
-                "Note: SEND_MAIL environment variale is not set to \"true\", no mail will be sent!"
+                "Note: Mailing disabled; 'SEND_MAIL' not 'true'."
             );
         }
     }
 
     pub fn send(&self, to: &str, subject: &str, text: &str, html: &str) {
-        let email = EmailBuilder::new()
+        let email: SendableEmail = EmailBuilder::new()
             .to(to)
             .from(self.from_address.as_ref())
             .subject(subject)
             .text(text)
             .html(html)
             .build()
-            .unwrap();
-
-        let sendable_email: SendableEmail = email.clone().into();
+            .unwrap()
+            .into();
 
         if self.actually_send {
             let mut mailer = SmtpClient::new_simple(self.smtp_server.as_str())
@@ -82,7 +80,7 @@ impl Mailer {
                 ))
                 .transport();
 
-            let result = mailer.send(sendable_email);
+            let result = mailer.send(email);
             println!(
                 r#"====================
 Sent email {:#?}
@@ -96,7 +94,7 @@ message:
             );
         } else {
             let mut mailer = StubTransport::new_positive();
-            let result = mailer.send(sendable_email);
+            let result = mailer.send(email);
             println!(
                 r#"====================
 Sent email {:#?}
